Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(615)

Unified Diff: components/password_manager/core/browser/password_manager_client.h

Issue 2721663002: Move Credentials when migrating to HSTS page (Closed)
Patch Set: Code Deduplication Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/browser/password_manager_client.h
diff --git a/components/password_manager/core/browser/password_manager_client.h b/components/password_manager/core/browser/password_manager_client.h
index e1a0cb3e145302d190fbb2da2efd95a2e06c3eef..0bc9a55e69152a223880591bfbe9262ff7e6a3dd 100644
--- a/components/password_manager/core/browser/password_manager_client.h
+++ b/components/password_manager/core/browser/password_manager_client.h
@@ -44,6 +44,7 @@ enum class CredentialSourceType {
// environment.
class PasswordManagerClient {
public:
+ using HSTSCallback = base::Callback<void(bool)>;
using CredentialsCallback =
base::Callback<void(const autofill::PasswordForm*)>;
@@ -59,9 +60,11 @@ class PasswordManagerClient {
// password manager is disabled, or in the presence of SSL errors on a page.
virtual bool IsFillingEnabledForCurrentPage() const;
- // Checks whether HTTP Strict Transport Security (HSTS) is active for the host
- // of the given origin.
- virtual bool IsHSTSActiveForHost(const GURL& origin) const;
+ // Checks asynchronously whether HTTP Strict Transport Security (HSTS) is
+ // active for the host of the given origin. Notifies |callback| with the
+ // result.
vasilii 2017/03/08 13:31:16 on the calling thread
jdoerrie 2017/03/09 18:35:49 Done.
+ virtual void PostHSTSQueryForHost(const GURL& origin,
+ const HSTSCallback& callback) const;
// Checks if the Credential Manager API is allowed to run on the page. It's
// not allowed while prerendering and the pre-rendered WebContents will be

Powered by Google App Engine
This is Rietveld 408576698